#
# spec file for package prometheus-cpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover_major 0
%define libname lib%{name}%{sover_major}_13

Name:           prometheus-cpp
Version:        0.13.0
Release:        bp160.1.7
Summary:        Prometheus client library for C++
License:        MIT
URL:            https://github.com/jupp0r/prometheus-cpp
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  zlib-devel

%description
Prometheus-cpp aims to enable Metrics-Driven Development for C++ services. It
implements the Prometheus Data Model, a powerful abstraction on which to collect
and expose metrics. It offers the possibility for metrics to be collected by
Prometheus, but other push/pull collections can be added as plugins.

%package -n %{libname}
Summary:        Shared libraries for prometheus-cpp

%description -n %{libname}
Prometheus-cpp aims to enable Metrics-Driven Development for C++ services. It
implements the Prometheus Data Model, a powerful abstraction on which to collect
and expose metrics. It offers the possibility for metrics to be collected by
Prometheus, but other push/pull collections can be added as plugins.

This package provides development files for prometheus-cpp.

%package devel
Summary:        Development files for prometheus-cpp
Requires:       %{libname} = %{version}

%description devel
Prometheus-cpp aims to enable Metrics-Driven Development for C++ services. It
implements the Prometheus Data Model, a powerful abstraction on which to collect
and expose metrics. It offers the possibility for metrics to be collected by
Prometheus, but other push/pull collections can be added as plugins.

This package provides development files for prometheus-cpp.

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/lib%{name}*.so.%{sover_major}*

%files devel
%{_includedir}/prometheus
%{_libdir}/cmake/%{name}
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/prometheus-cpp*.pc

%changelog
* Tue Sep 17 2024 ncutler@suse.com - 0.13.0
- Update to version 0.13.0:
  * fix(core): Locale-independent floating-point serialization
  * chore: prepare 0.13.0 release
  * ci: iwyu entered Debian Sid
  * chore(pull): Use civetweb 1.15
  * chore: Use Google Benchmark 1.6.0
  * docs: update Readme
  * feat(pull): Use civetweb 1.15
  * ci: Run iwyu 8.16 from Debian Experimental
  * chore: update curl and Google Benchmark
  * ci: select proper test configuration
  * chore: add missing include for iwyu
  * chore: update googletest and curl
  * Add const/reserve (#495)
  * Make summary quantiles non-const (#493)
  * Update handler.cc
  * Update handler.cc
  * fix make_unique
* Mon Apr  8 2024 Nathan Cutler <ncutler@suse.com>
- spec: add Copyright boilerplate
* Thu Aug 10 2023 Wolfgang Rosenauer <wr@rosenauer.org>
- added package suffix
* Wed Aug  4 2021 mrueckert@suse.de
- Update to version 0.12.3:
  * ci: Run iwyu 8.16 from Debian Experimental
  * chore: update curl and Google Benchmark
  * ci: select proper test configuration
  * chore: add missing include for iwyu
  * chore: update googletest and curl
  * Add const/reserve (#495)
  * Make summary quantiles non-const (#493)
  * Update handler.cc
  * Update handler.cc
  * fix make_unique
  * Prepare v0.12.3 release
  * pull: Install header files for embedded civetweb
  * chore: use google benchmark 1.5.3
  * chore: use curl 7.76.1
  * pull: Prevent ABI break due to #479
  * CMakeLists: Change cmake min version to 3.14
  * core: add method to query family if metric exists (#482)
  * Add CivetCallbacks to Exposer ctor
  * chore: use civetweb 1.14
  * chore: use curl 7.76.0
  * push: Always use POST (regardless of body presence)
  * core: avoid collecting empty metric families
  * pull: Announce utf-8 content encoding
  * chore: prepare prometheus-cpp 0.12.2
  * core: Replace name check regex (#462)
  * core: reject duplicate label names (#463)
  * ci: Add clang-format linting (#464)
  * feat(cmake): Generate pkg-config files
  * feat(iwyu): Organize includes with include-what-you-use
  * Add conan reference to readme
  * core: Fix usage of std::to_chars
  * chore: start prometheus-cpp 0.12.1 development cycle
  * fix: use printf %%g or std::to_chars to serialize doubles
  * ci: Add workflow to create tarball including submodules
  * Added missing include
  * pull: improve code coverage
  * ci: Use GitHub Actions to deploy documentation
  * ci: use lcov for coverage
  * pull: don't trigger failing authentication due to civetweb/civetweb#954
  * pull: don't set auth handler to nullptr to avoid civetweb bug
  * pull: test authentication and compression
  * ci: Make Coverage workflow more fine-grained
  * pull: Add better example
  * ci: Make CMake workflow more fine-grained
  * ci: Run bazel from separate workflow
  * chore: Raise version to v0.12.0 due to changed public interface
  * pull: Add RemoveCollectable
  * pull: Work-around assertion and race-condition in auth handler
  * pull: Add integration test for exposer
  * push: Remove expired weak pointers to avoid leak
  * pull: Remove expired weak pointers to avoid leak
  * chore: remove extra block
  * chore: re-format with buildifier 3.5.0
  * chore: re-format with clang-format 11
  * pull: do not export BasicAuthHandler
  * core: enforce proper metric and label names
  * pull: Use internal base64 decoding function to avoid dependency (#417)
  * pull: work-around missing winsock lib in civetweb
  * build: Bump library interface due to changes Histogram class
  * chore: use max_digits10 instead of magic number
  * feat: allow selection of MSVC runtime library
  * Fix insufficiently precise value rendering
  * core: Add test for negative observed histogram value
  * Use a gauge for the histogram sum
  * core: allow logically negative gauge increments and decrements
  * packaging: Add shlib generation.
  * push: use curl 7.73.0
  * ci: use latest bazel
  * fix(cmake): Fix warning in CheckAtomic
  * chore: Raise version to v0.10.0 due to changed public interface
  * chore: Use Bazel 3.5.1
  * chore: Use civetweb 1.13
  * chore: Use curl 1.72.0
  * chore: Use google-benchmark 1.5.2
  * push: slightly refactor gateway
  * formatting
  * core: Explicitly link against libatomic when needed
  * ci: require fixed bazel version
  * Use mutex to protect http operation
  * Fix coverage from forks (#391)
  * Use indirection to avoid curl include
  * Reuse curl handle
  * Avoid race when registering a collectable
  * chore(bazel): Use Google Benchmark 1.5.1
  * Use header-only cppcodec lib and fix build
  * Add support for HTTP Basic Auth on scraping endpoints
  * Add base64 encoding/decoding dependency
  * Extend existing exposer interface
  * Add support for serving multiple paths
  * ci: Use preinstalled Bazel
  * chore(pull): refactor collection code into metrics_collector
  * doc: Use README.md as mainpage
  * ci: Fix documentation generation
  * doc: Add brief instructions how to consume
  * Add reason for setting CMAKE_INSTALL_DEFAULT_DIRECTORY_PERMISSIONS
  * CMake: Fix directory permissions on installation
  * chore: use imported CMake curl target
  * feat: Add project to test CMake export
  * fix: Properly export civetweb object library
  * chore: Use civetweb 1.12
  * pull: Add support for https and client certificates
  * ci: use vcpkg for external dependencies
  * chore(push): Update curl to 7.69.1
  * core: Skip serialization test if locale is not available
  * fix(cmake): Explicitly initialize package version for older cmake
  * feat(core): Expect working German locale
  * Add cpack configuration and readme
  * CMake: Add support for Debian and RPM package generation
  * feat(pull): Add getter for listening ports
  * chore: Use libcurl 7.68.0
  * Include missing <ostream>
  * Avoid copying the histogram metric buckets. (#331)
  * Update Bazel build instructions (#326)
  * Make Collect methods const (#323)
  * Fix coverage
  * Fix submodule checkout
  * fix(github): Use macos-latest
  * chore(dependencies): Update Google Benchmark and Test to latest release
  * feat(core): Improve text_serializer.cc coverage
  * fix(coverage): Use Ubuntu 16.04 for coverage
  * fix(core): Properly serialize newlines in label values
  * feat(core): Improve text_serializer.cc coverage
  * feat(core): Improve family.cc coverage
  * fix(ci): Also build with Bazel on Windows
  * feat(coverage): Use GitHub Actions for code coverage
  * chore(bazel): Move repositories.bzl to bazel subdir
  * chore(curl): Use curl 7.66.0
  * chore(bazel): curl must not expect stropts.h header on Linux
  * chore(bazel): Use maybe function from bazel_tools
* Mon Nov  4 2019 Michał Rostecki <mrostecki@opensuse.org>
- Initial release
